@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE project
-   Copyright (C) 1998-2005 David Faure <faure@kde.org>
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998-2005 David Faure <faure@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "konqview.h"
@@ -23,7 +10,7 @@
 #include "KonqViewAdaptor.h"
 #include "konqsettingsxt.h"
 #include "konqframestatusbar.h"
-#include "konqrun.h"
+#include "urlloader.h"
 #include <konq_events.h>
 #include "konqviewmanager.h"
 #include "konqtabs.h"
@@ -84,7 +71,7 @@ KonqView::KonqView(KonqViewFactory &viewFactory,
     m_bLockHistory = false;
     m_doPost = false;
     m_pMainWindow = mainWindow;
-    m_pRun = nullptr;
+    m_loader = nullptr;
     m_pPart = nullptr;
 
     m_service = service;
@@ -136,10 +123,15 @@ KonqView::~KonqView()
     qDeleteAll(m_lstHistory);
     m_lstHistory.clear();
 
-    setRun(nullptr);
+    setUrlLoader(nullptr);
     //qCDebug(KONQUEROR_LOG) << this << "done";
 }
 
+bool KonqView::isWebEngineView() const
+{
+    return m_service->desktopEntryName() == QLatin1String("webenginepart");
+}
+
 void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
                        const QString &nameFilter, bool tempFile)
 {
@@ -220,6 +212,9 @@ void KonqView::openUrl(const QUrl &url, const QString &locationBarURL,
 
     aboutToOpenURL(url, args);
 
+    if (args.metaData().contains("urlRequestedByApp") && isWebEngineView()) {
+        m_pPart->setProperty("urlRequestedByApp", url);
+    }
     m_pPart->openUrl(url);
 
     updateHistoryEntry(true);
@@ -592,8 +587,8 @@ void KonqView::slotCompleted(bool hasPending)
 
     if (!m_bGotIconURL && !m_bAborted) {
         if (KonqSettings::enableFavicon() == true) {
-            // Try to get /favicon.ico
-            if (supportsMimeType(QStringLiteral("text/html")) && url().scheme().startsWith(QLatin1String("http"))) {
+            // Try to get /favicon.ico. KonqPixmapProvider::downloadHostIcon does nothing if the URL is not http(s)
+            if (supportsMimeType(QStringLiteral("text/html"))) {
                 KonqPixmapProvider::self()->downloadHostIcon(url());
             }
         }
@@ -893,30 +888,30 @@ QUrl KonqView::url() const
 QUrl KonqView::upUrl() const
 {
     QUrl currentURL;
-    if (m_pRun) {
-        currentURL = m_pRun->url();
+    if (m_loader) {
+        currentURL = m_loader->url();
     } else {
         currentURL = QUrl::fromUserInput(m_sLocationBarURL);
     }
     return KIO::upUrl(currentURL);
 }
 
-void KonqView::setRun(KonqRun *run)
+void KonqView::setUrlLoader(UrlLoader *run)
 {
-    if (m_pRun) {
-        // Tell the KonqRun to abort, but don't delete it ourselves.
+    if (m_loader) {
+        // Tell the UrlLoader to abort, but don't delete it ourselves.
         // It could be showing a message box right now. It will delete itself anyway.
-        m_pRun->abort();
+        m_loader->abort();
         // finish() will be emitted later (when back to event loop)
         // and we don't want it to call slotRunFinished (which stops the animation and stop button).
-        m_pRun->disconnect(m_pMainWindow);
+        m_loader->disconnect(m_pMainWindow);
         if (!run) {
             frame()->unsetCursor();
         }
     } else if (run) {
         frame()->setCursor(Qt::BusyCursor);
     }
-    m_pRun = run;
+    m_loader = run;
 }
 
 void KonqView::stop()
@@ -935,16 +930,16 @@ void KonqView::stop()
         m_pKonqFrame->statusbar()->slotLoadingProgress(-1);
         setLoading(false, false);
     }
-    if (m_pRun) {
+    if (m_loader) {
         // Revert to working URL - unless the URL was typed manually
         // This is duplicated with KonqMainWindow::slotRunFinished, but we can't call it
         //   since it relies on sender()...
-        if (currentHistoryEntry() && m_pRun->typedUrl().isEmpty()) {   // not typed
+        if (currentHistoryEntry() && m_loader->request().typedUrl.isEmpty()) {   // not typed
             setLocationBarURL(currentHistoryEntry()->locationBarURL);
             setPageSecurity(currentHistoryEntry()->pageSecurity);
         }
 
-        setRun(nullptr);
+        setUrlLoader(nullptr);
         m_pKonqFrame->statusbar()->slotLoadingProgress(-1);
     }
     if (!m_bLockHistory && m_lstHistory.count() > 0) {
@@ -1224,6 +1219,16 @@ bool KonqView::supportsMimeType(const QString &mimeType) const
     return false;
 }
 
+bool KonqView::isWebBrowsingPart() const
+{
+    if (!m_pPart) {
+        return false;
+    }
+    const QString partName = m_pPart->componentName();
+    return partName == QLatin1String("webenginepart") || partName == QLatin1String("khtml") || partName == QLatin1String("kwebkitpart");
+}
+
+
 void HistoryEntry::saveConfig(KConfigGroup &config, const QString &prefix, const KonqFrameBase::Options &options)
 {
     if (options & KonqFrameBase::SaveUrls) {
